@@ -23,7 +23,7 @@ class ChartOrTableSeriesSpec(BaseModel):
     name: str
     tag: str | None = None
 
-    def has_tag(self, tag: str) -> bool:
+    def has_tag(self, tag: str | None) -> bool:
         return tag == self.tag
 
 
@@ -31,8 +31,12 @@ class TableSpec(BaseModel):
     series: list[ChartOrTableSeriesSpec]
 
     def find_series_id_by_name(self, series_name: str, *, tag: str | None = None) -> str | None:
+        """Find series ID by its name.
+
+        When tag is None, return the series without a tag (and not any tag).
+        """
         for series_spec in self.series:
-            if series_spec.name == series_name and (tag is None or series_spec.has_tag(tag)):
+            if series_spec.name == series_name and series_spec.has_tag(tag):
                 return series_spec.id
         return None
 
@@ -42,8 +46,8 @@ class TableSpec(BaseModel):
                 return series_spec
         return None
 
-    def get_series_ids(self) -> set[str]:
-        return {series_id_or_spec.id for series_id_or_spec in self.series}
+    def get_series_ids(self) -> list[str]:
+        return [series_id_or_spec.id for series_id_or_spec in self.series]
 
 
 DataLabelPositionT: TypeAlias = Literal["last_point"]
