@@ -1,4 +1,3 @@
-from pathlib import Path
 from types import ModuleType
 from typing import Iterator, cast
 
@@ -9,6 +8,7 @@ from pptx.shapes.graphfrm import GraphicFrame
 from pptx.slide import Slide, Slides
 
 from dbnomics_pptx_tools.charts import update_chart
+from dbnomics_pptx_tools.repo import SeriesRepo
 from dbnomics_pptx_tools.tables import extract_table_zones, format_table, update_table
 
 from .metadata import PresentationMetadata, SlideMetadata
@@ -58,20 +58,27 @@ def iter_line_series(series_collection: SeriesCollection, *, strict: bool = True
 def update_slide_charts(
     slide: Slide,
     *,
-    dbnomics_api_cache_dir: Path,
+    repo: SeriesRepo,
     slide_metadata: SlideMetadata,
 ):
     slide_shapes = list(iter_chart_shapes(slide))
     for chart_pos, chart_shape in enumerate(slide_shapes, start=1):
-        logger.debug("Processing chart %d with name %r...", chart_pos, chart_shape.name)
-        chart_spec = slide_metadata.charts.get(chart_shape.name)
+        chart_name = chart_shape.name
+        logger.debug("Updating chart %d/%d with name %r...", chart_pos, len(slide_shapes), chart_name)
+
+        chart_spec = slide_metadata.charts.get(chart_name)
         if chart_spec is None:
-            logger.warning("No spec was found for chart %d with name %r, ignoring chart", chart_pos, chart_shape.name)
+            logger.warning(
+                "Chart with name %r was found in the presentation file, "
+                "but no corresponding block was found in the YAML file, ignoring chart",
+                chart_name,
+            )
             continue
+
         update_chart(
             chart_shape,
             chart_spec=chart_spec,
-            dbnomics_api_cache_dir=dbnomics_api_cache_dir,
+            repo=repo,
             slide=slide,
         )
 
@@ -79,16 +86,28 @@ def update_slide_charts(
 def update_slide_tables(
     slide: Slide,
     *,
-    adhoc_tables_module: ModuleType | None,
-    dbnomics_api_cache_dir: Path,
+    adhoc_module: ModuleType | None,
+    repo: SeriesRepo,
     slide_metadata: SlideMetadata,
 ):
     table_shapes = list(iter_table_shapes(slide))
     for table_pos, table_shape in enumerate(table_shapes, start=1):
-        logger.debug("Processing table %d...", table_pos)
         table = table_shape.table
         table_name = table_shape.name
-        table_zones = extract_table_zones(table, adhoc_tables_module=adhoc_tables_module, table_name=table_name)
+
+        logger.debug("Updating table %d/%d with name %r...", table_pos, len(table_shapes), table_name)
+
+        table_spec = slide_metadata.tables.get(table_name)
+        if not table_spec:
+            logger.warning(
+                "Table with name %r was found in the presentation file, "
+                "but no corresponding block was found in the YAML file, ignoring table, showing table preview:\n%s",
+                table_name,
+                format_table(table),
+            )
+            continue
+
+        table_zones = extract_table_zones(table, adhoc_module=adhoc_module, table_name=table_name)
         if table_zones is None:
             logger.warning(
                 "Could not extract the zones of table %d with name %r, ignoring table, showing table preview:\n%s",
@@ -97,20 +116,11 @@ def update_slide_tables(
                 format_table(table),
             )
             continue
-        logger.debug("Updating table %d with name %r...", table_pos, table_name)
-        table_spec = slide_metadata.tables.get(table_name)
-        if not table_spec:
-            logger.warning(
-                "No spec was found for table %d with name %r, ignoring table, showing table preview:\n%s",
-                table_pos,
-                table_name,
-                format_table(table),
-            )
-            continue
+
         update_table(
             table,
-            adhoc_tables_module=adhoc_tables_module,
-            dbnomics_api_cache_dir=dbnomics_api_cache_dir,
+            adhoc_module=adhoc_module,
+            repo=repo,
             table_name=table_name,
             table_spec=table_spec,
             table_zones=table_zones,
@@ -120,10 +130,10 @@ def update_slide_tables(
 def update_slides(
     prs: Presentation,
     *,
-    adhoc_tables_module: ModuleType | None,
-    dbnomics_api_cache_dir: Path,
+    adhoc_module: ModuleType | None,
     only_slides: set[int] | None = None,
     presentation_metadata: PresentationMetadata,
+    repo: SeriesRepo,
 ):
     for slide_pos, slide in enumerate(cast(Slides, prs.slides), start=1):
         if only_slides is not None and slide_pos not in only_slides:
@@ -134,16 +144,17 @@ def update_slides(
         slide_title = slide.shapes.title.text
         slide_metadata = presentation_metadata.slides.get(slide_title)
         if slide_metadata is None:
+            logger.warning("Slide %d with title %r has no metadata, ignoring slide", slide_pos, slide_title)
             continue
         logger.debug("Updating slide %d with title %r...", slide_pos, slide_title)
         update_slide_charts(
             slide,
-            dbnomics_api_cache_dir=dbnomics_api_cache_dir,
+            repo=repo,
             slide_metadata=slide_metadata,
         )
         update_slide_tables(
             slide,
-            adhoc_tables_module=adhoc_tables_module,
-            dbnomics_api_cache_dir=dbnomics_api_cache_dir,
+            adhoc_module=adhoc_module,
+            repo=repo,
             slide_metadata=slide_metadata,
         )
